@@ -19,7 +19,7 @@ from unittest import mock
 import pytest
 import torch
 
-from pl_examples import DALI_AVAILABLE
+from pl_examples import _DALI_AVAILABLE
 
 ARGS_DEFAULT = """
 --default_root_dir %(tmpdir)s \
@@ -38,28 +38,20 @@ ARGS_DP = ARGS_DEFAULT + """
 --accelerator dp \
 """
 
-ARGS_DP_AMP = ARGS_DP + """
---precision 16 \
-"""
-
-ARGS_DDP = ARGS_DEFAULT + """
---gpus 2 \
---accelerator ddp \
---precision 16 \
-"""
-
-ARGS_DDP_AMP = ARGS_DEFAULT + """
+ARGS_AMP = """
 --precision 16 \
 """
 
 
-@pytest.mark.parametrize('import_cli', [
-    'pl_examples.basic_examples.simple_image_classifier',
-    'pl_examples.basic_examples.backbone_image_classifier',
-    'pl_examples.basic_examples.autoencoder',
-])
+@pytest.mark.parametrize(
+    'import_cli', [
+        'pl_examples.basic_examples.simple_image_classifier',
+        'pl_examples.basic_examples.backbone_image_classifier',
+        'pl_examples.basic_examples.autoencoder',
+    ]
+)
 @pytest.mark.skipif(torch.cuda.device_count() < 2, reason="test requires multi-GPU machine")
-@pytest.mark.parametrize('cli_args', [ARGS_DP, ARGS_DP_AMP])
+@pytest.mark.parametrize('cli_args', [ARGS_DP, ARGS_DP + ARGS_AMP])
 def test_examples_dp(tmpdir, import_cli, cli_args):
 
     module = importlib.import_module(import_cli)
@@ -70,29 +62,13 @@ def test_examples_dp(tmpdir, import_cli, cli_args):
         module.cli_main()
 
 
-# ToDo: fix this failing example
-# @pytest.mark.parametrize('import_cli', [
-#     'pl_examples.basic_examples.simple_image_classifier',
-#     'pl_examples.basic_examples.backbone_image_classifier',
-#     'pl_examples.basic_examples.autoencoder',
-# ])
-# @pytest.mark.skipif(torch.cuda.device_count() < 2, reason="test requires multi-GPU machine")
-# @pytest.mark.parametrize('cli_args', [ARGS_DDP, ARGS_DDP_AMP])
-# def test_examples_ddp(tmpdir, import_cli, cli_args):
-#
-#     module = importlib.import_module(import_cli)
-#     # update the temp dir
-#     cli_args = cli_args % {'tmpdir': tmpdir}
-#
-#     with mock.patch("argparse._sys.argv", ["any.py"] + cli_args.strip().split()):
-#         module.cli_main()
-
-
-@pytest.mark.parametrize('import_cli', [
-    'pl_examples.basic_examples.simple_image_classifier',
-    'pl_examples.basic_examples.backbone_image_classifier',
-    'pl_examples.basic_examples.autoencoder',
-])
+@pytest.mark.parametrize(
+    'import_cli', [
+        'pl_examples.basic_examples.simple_image_classifier',
+        'pl_examples.basic_examples.backbone_image_classifier',
+        'pl_examples.basic_examples.autoencoder',
+    ]
+)
 @pytest.mark.parametrize('cli_args', [ARGS_DEFAULT])
 def test_examples_cpu(tmpdir, import_cli, cli_args):
 
@@ -104,7 +80,7 @@ def test_examples_cpu(tmpdir, import_cli, cli_args):
         module.cli_main()
 
 
-@pytest.mark.skipif(not DALI_AVAILABLE, reason="Nvidia DALI required")
+@pytest.mark.skipif(not _DALI_AVAILABLE, reason="Nvidia DALI required")
 @pytest.mark.skipif(not torch.cuda.is_available(), reason="test requires GPU machine")
 @pytest.mark.skipif(platform.system() != 'Linux', reason='Only applies to Linux platform.')
 @pytest.mark.parametrize('cli_args', [ARGS_GPU])
