@@ -11,25 +11,29 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from pytorch_lightning.metrics.metric import Metric
-
-from pytorch_lightning.metrics.classification import (
+from pytorch_lightning.metrics.classification import (  # noqa: F401
     Accuracy,
-    Precision,
-    Recall,
-    ConfusionMatrix,
-    PrecisionRecallCurve,
+    AUC,
+    AUROC,
     AveragePrecision,
-    ROC,
-    FBeta,
+    ConfusionMatrix,
     F1,
+    FBeta,
+    HammingDistance,
+    IoU,
+    Precision,
+    PrecisionRecallCurve,
+    Recall,
+    ROC,
+    StatScores,
 )
-
-from pytorch_lightning.metrics.regression import (
-    MeanSquaredError,
-    MeanAbsoluteError,
-    MeanSquaredLogError,
+from pytorch_lightning.metrics.metric import Metric, MetricCollection  # noqa: F401
+from pytorch_lightning.metrics.regression import (  # noqa: F401
     ExplainedVariance,
+    MeanAbsoluteError,
+    MeanSquaredError,
+    MeanSquaredLogError,
     PSNR,
+    R2Score,
     SSIM,
 )
