@@ -11,14 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import Any, Callable, Optional
+
 import torch
-from typing import Any, Callable, Optional, Union
 
-from pytorch_lightning.metrics.metric import Metric
 from pytorch_lightning.metrics.functional.mean_absolute_error import (
+    _mean_absolute_error_compute,
     _mean_absolute_error_update,
-    _mean_absolute_error_compute
 )
+from pytorch_lightning.metrics.metric import Metric
 
 
 class MeanAbsoluteError(Metric):
