@@ -18,8 +18,9 @@ from pytorch_lightning.utilities.exceptions import MisconfigurationException
 class CallbackHookNameValidator:
 
     @staticmethod
-    def check_logging_in_callbacks(current_hook_fx_name: str = None, on_step: bool = None,
-                                   on_epoch: bool = None) -> None:
+    def check_logging_in_callbacks(
+        current_hook_fx_name: str = None, on_step: bool = None, on_epoch: bool = None
+    ) -> None:
         if current_hook_fx_name is None:
             return
 
@@ -44,6 +45,11 @@ class CallbackHookNameValidator:
                 f"{current_hook_fx_name} function doesn't support logging using self.log() yet."
             )
 
+    @staticmethod
+    def _on_before_accelerator_backend_setup_log():
+        """Called before accelerator is being setup"""
+        return None
+
     @staticmethod
     def _setup_log():
         """Called when fit or test begins"""
