@@ -13,15 +13,15 @@
 # limitations under the License.
 import torch
 
-from pytorch_lightning.core.step_result import EvalResult, Result
+from pytorch_lightning.core.step_result import Result
 from pytorch_lightning.trainer.supporters import PredictionCollection
-from pytorch_lightning.utilities.distributed import rank_zero_warn
-from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.model_utils import is_overridden
-from pytorch_lightning.utilities.warning_utils import WarningCache
+from pytorch_lightning.utilities.apply_func import apply_to_collection
+from pytorch_lightning.utilities.model_helpers import is_overridden
+from pytorch_lightning.utilities.warnings import WarningCache
 
 
 class EvaluationLoop(object):
+
     def __init__(self, trainer):
         self.trainer = trainer
         self.outputs = []
@@ -38,7 +38,6 @@ class EvaluationLoop(object):
         self.trainer.test_dataloaders = None
         self.trainer.val_dataloaders = None
         self.trainer.running_sanity_check = False
-        self.trainer.testing = False
 
         # when .test() is called, it sets this
         self.trainer.tested_ckpt_path = None
@@ -48,7 +47,7 @@ class EvaluationLoop(object):
 
     def get_evaluation_dataloaders(self, max_batches):
         # select dataloaders
-        model = self.trainer.get_model()
+        model = self.trainer.lightning_module
 
         # select dataloaders
         if self.trainer.testing:
@@ -80,15 +79,15 @@ class EvaluationLoop(object):
         else:
             self.trainer.call_hook('on_validation_start', *args, **kwargs)
 
-    def on_evaluation_model_eval(self, *args, **kwargs):
-        model_ref = self.trainer.get_model()
+    def on_evaluation_model_eval(self, *_, **__):
+        model_ref = self.trainer.lightning_module
         if self.trainer.testing:
             model_ref.on_test_model_eval()
         else:
             model_ref.on_validation_model_eval()
 
-    def on_evaluation_model_train(self, *args, **kwargs):
-        model_ref = self.trainer.get_model()
+    def on_evaluation_model_train(self, *_, **__):
+        model_ref = self.trainer.lightning_module
         if self.trainer.testing:
             model_ref.on_test_model_train()
         else:
@@ -101,17 +100,12 @@ class EvaluationLoop(object):
             self.trainer.call_hook('on_validation_end', *args, **kwargs)
 
     def reload_evaluation_dataloaders(self):
-        model = self.trainer.get_model()
+        model = self.trainer.lightning_module
         if self.trainer.testing:
             self.trainer.reset_test_dataloader(model)
         else:
             self.trainer.reset_val_dataloader(model)
 
-    def is_using_eval_results(self):
-        outputs = self.outputs
-        using_eval_result = len(outputs) > 0 and len(outputs[0]) > 0 and isinstance(outputs[0][0], EvalResult)
-        return using_eval_result
-
     def setup(self, model, max_batches, dataloaders):
         # bookkeeping
         self.outputs = []
@@ -123,6 +117,7 @@ class EvaluationLoop(object):
 
         self.max_batches = max_batches
         self.num_dataloaders = self._get_num_dataloaders(dataloaders)
+        self._predictions = [[] for _ in range(self.num_dataloaders)]
 
     def on_evaluation_epoch_start(self, *args, **kwargs):
         if self.trainer.testing:
@@ -135,13 +130,9 @@ class EvaluationLoop(object):
         args = [batch, batch_idx]
 
         multiple_val_loaders = (
-            not self.trainer.testing
-            and self._get_num_dataloaders(self.trainer.val_dataloaders) > 1
-        )
-        multiple_test_loaders = (
-            self.trainer.testing
-            and self._get_num_dataloaders(self.trainer.test_dataloaders) > 1
+            not self.trainer.testing and self._get_num_dataloaders(self.trainer.val_dataloaders) > 1
         )
+        multiple_test_loaders = (self.trainer.testing and self._get_num_dataloaders(self.trainer.test_dataloaders) > 1)
 
         if multiple_test_loaders or multiple_val_loaders:
             args.append(dataloader_idx)
@@ -160,15 +151,17 @@ class EvaluationLoop(object):
         # configure args
         args = self._build_args(batch, batch_idx, dataloader_idx)
 
-        model_ref = self.trainer.get_model()
+        model_ref = self.trainer.lightning_module
         model_ref._results = Result()
-        # run actual test step
-        if self.trainer.testing:
+
+        if self.testing:
             model_ref._current_fx_name = "test_step"
-            output = self.trainer.accelerator_backend.test_step(args)
+            with self.trainer.profiler.profile("test_step"):
+                output = self.trainer.accelerator.test_step(args)
         else:
             model_ref._current_fx_name = "validation_step"
-            output = self.trainer.accelerator_backend.validation_step(args)
+            with self.trainer.profiler.profile("validation_step"):
+                output = self.trainer.accelerator.validation_step(args)
 
         # capture any logged information
         self.trainer.logger_connector.cache_logged_metrics()
@@ -177,11 +170,6 @@ class EvaluationLoop(object):
         if is_result_obj:
             output.track_batch_size(batch)
 
-        # allow only EvalResult when using structured results (from val_step)
-        if is_result_obj and not isinstance(output, EvalResult):
-            m = 'only EvalResults or dicts are allowed from validation_step'
-            raise MisconfigurationException(m)
-
         return output
 
     def evaluation_step_end(self, *args, **kwargs):
@@ -195,10 +183,8 @@ class EvaluationLoop(object):
         # unset dataloder_idx in model
         self.trainer.logger_connector.evaluation_epoch_end(self.trainer.testing)
 
-        using_eval_result = self.is_using_eval_results()
-
         # call the model epoch end
-        deprecated_results = self.__run_eval_epoch_end(self.num_dataloaders, using_eval_result)
+        deprecated_results = self.__run_eval_epoch_end(self.num_dataloaders)
 
         # enable returning anything
         for i, r in enumerate(deprecated_results):
@@ -212,11 +198,15 @@ class EvaluationLoop(object):
         eval_loop_results = self.trainer.logger_connector.get_evaluate_epoch_results()
         return eval_loop_results
 
-    def __run_eval_epoch_end(self, num_dataloaders, using_eval_result):
-        model = self.trainer.get_model()
+    def __run_eval_epoch_end(self, num_dataloaders):
+        model = self.trainer.lightning_module
 
         # with a single dataloader don't pass an array
         outputs = self.outputs
+
+        # free memory
+        self.outputs = []
+
         eval_results = outputs
         if num_dataloaders == 1:
             eval_results = outputs[0]
@@ -225,16 +215,12 @@ class EvaluationLoop(object):
 
         if self.trainer.testing:
             if is_overridden('test_epoch_end', model=model):
-                if using_eval_result:
-                    eval_results = self.__gather_epoch_end_eval_results(outputs)
                 model._current_fx_name = 'test_epoch_end'
                 eval_results = model.test_epoch_end(eval_results)
                 user_reduced = True
 
         else:
             if is_overridden('validation_epoch_end', model=model):
-                if using_eval_result:
-                    eval_results = self.__gather_epoch_end_eval_results(outputs)
                 model._current_fx_name = 'validation_epoch_end'
                 eval_results = model.validation_epoch_end(eval_results)
                 user_reduced = True
@@ -249,14 +235,11 @@ class EvaluationLoop(object):
                 ' To log, use self.log(...) or self.write(...) directly in the LightningModule'
             )
 
-        if using_eval_result and not user_reduced:
-            eval_results = self.__auto_reduce_result_objs(outputs)
-
         if not isinstance(eval_results, list):
             eval_results = [eval_results]
 
         # track depreceated metrics
-        self.trainer.logger_connector.track_metrics_deprecated(eval_results, using_eval_result)
+        self.trainer.logger_connector.track_metrics_deprecated(eval_results)
 
         return eval_results
 
@@ -290,10 +273,23 @@ class EvaluationLoop(object):
 
         return eval_results
 
+    def on_predict_epoch_end(self):
+        self.trainer._progress_bar_callback.on_test_end(self.trainer, self.trainer.lightning_module)
+
+        results = self._predictions
+
+        def _convert_to_numpy(v):
+            return v.cpu().numpy()
+
+        results = apply_to_collection(results, torch.Tensor, _convert_to_numpy)
+
+        return results, None
+
     def on_evaluation_batch_start(self, batch, batch_idx, dataloader_idx):
         # set dataloader_idx to model and track batch_size
         self.trainer.logger_connector.on_evaluation_batch_start(
-            self.trainer.testing, batch, dataloader_idx, self.num_dataloaders)
+            self.trainer.testing, batch, dataloader_idx, self.num_dataloaders
+        )
 
         if self.trainer.testing:
             self.trainer.call_hook('on_test_batch_start', batch, batch_idx, dataloader_idx)
@@ -326,15 +322,14 @@ class EvaluationLoop(object):
         else:
             self.trainer.call_hook('on_validation_epoch_end', *args, **kwargs)
 
+        self.trainer.call_hook('on_epoch_end')
+
     def log_evaluation_step_metrics(self, output, batch_idx):
         if self.trainer.running_sanity_check:
             return
 
         step_log_metrics = {}
         step_pbar_metrics = {}
-        if isinstance(output, EvalResult):
-            step_log_metrics = output.get_batch_log_metrics(include_forked_originals=False)
-            step_pbar_metrics = output.get_batch_pbar_metrics(include_forked_originals=False)
 
         self.__log_result_step_metrics(step_log_metrics, step_pbar_metrics, batch_idx)
 
