@@ -13,8 +13,18 @@
 # limitations under the License.
 import torch
 
+from pytorch_lightning.utilities.exceptions import MisconfigurationException
+
 
 def pick_multiple_gpus(nb):
+    if nb == 0:
+        raise MisconfigurationException(
+            r"auto_select_gpus=True, gpus=0 is not a valid configuration.\
+            Please select a valid number of GPU resources when using auto_select_gpus."
+        )
+
+    nb = torch.cuda.device_count() if nb == -1 else nb
+
     picked = []
     for _ in range(nb):
         picked.append(pick_single_gpu(exclude_gpus=picked))
