@@ -54,12 +54,12 @@ class InternalDebugger(object):
         self.dataloader_sequence_calls = []
 
     def track_event(
-            self,
-            evt_type: str,
-            evt_value: Any = None,
-            global_rank: Optional[int] = None,
-            local_rank: Optional[int] = None,
-            comment: str = ''
+        self,
+        evt_type: str,
+        evt_value: Any = None,
+        global_rank: Optional[int] = None,
+        local_rank: Optional[int] = None,
+        comment: str = ''
     ) -> None:
         self.events.append({
             "timestamp": time.time(),
@@ -87,6 +87,7 @@ class InternalDebugger(object):
         for dl in dataloaders:
             try:
                 length = len(dl)
+            # todo: specify the possible exception
             except Exception:
                 length = -1
             lengths.append(length)
@@ -120,13 +121,16 @@ class InternalDebugger(object):
         self.saved_train_losses.append(loss_dict)
 
     @enabled_only
-    def track_lr_schedulers_update(self, batch_idx, interval, scheduler_idx, old_lr, new_lr, monitor_key=None):
+    def track_lr_schedulers_update(
+        self, batch_idx, interval, scheduler_idx, old_lr, new_lr, monitor_key=None, monitor_val=None
+    ):
         loss_dict = {
             'batch_idx': batch_idx,
             'interval': interval,
             'scheduler_idx': scheduler_idx,
             'epoch': self.trainer.current_epoch,
             'monitor_key': monitor_key,
+            'monitor_val': monitor_val,
             'old_lr': old_lr,
             'new_lr': new_lr
         }
